@@ -91,7 +91,134 @@ bootdata.subject.msm <- function(x) {
 ### e.g. qmatrix, ematrix, hmodel, ...
 ### Put in help file that these must be in the working environment.
 
-boot.msm <- function(x, stat=pmatrix.msm, B=1000, file=NULL, cores=NULL){
+
+
+#' Bootstrap resampling for multi-state models
+#' 
+#' Draw a number of bootstrap resamples, refit a \code{\link{msm}} model to the
+#' resamples, and calculate statistics on the refitted models.
+#' 
+#' The bootstrap datasets are computed by resampling independent pairs of
+#' observations at successive times (for non-hidden models without censoring),
+#' or independent individual series (for hidden models or models with
+#' censoring).  Therefore this approach doesn't work if, for example, the data
+#' for a HMM consist of a series of observations from just one individual, and
+#' is inaccurate for small numbers of independent transitions or individuals.
+#' 
+#' Confidence intervals or standard errors for the corresponding statistic can
+#' be calculated by summarising the returned list of \code{B} replicated
+#' outputs.  This is currently implemented for most the output functions
+#' \code{\link{qmatrix.msm}}, \code{\link{ematrix.msm}},
+#' \code{\link{qratio.msm}}, \code{\link{pmatrix.msm}},
+#' \code{\link{pmatrix.piecewise.msm}}, \code{\link{totlos.msm}} and
+#' \code{\link{prevalence.msm}}.  For other outputs, users will have to write
+#' their own code to summarise the output of \code{\link{boot.msm}}.
+#' 
+#' Most of \pkg{msm}'s output functions present confidence intervals based on
+#' asymptotic standard errors calculated from the Hessian. These are expected
+#' to be underestimates of the true standard errors (Cramer-Rao lower bound).
+#' Some of these functions use a further approximation, the delta method (see
+#' \code{\link{deltamethod}}) to obtain standard errors of transformed
+#' parameters. Bootstrapping should give a more accurate estimate of the
+#' uncertainty.
+#' 
+#' An alternative method which is less accurate though faster than
+#' bootstrapping, but more accurate than the delta method, is to draw a sample
+#' from the asymptotic multivariate normal distribution implied by the maximum
+#' likelihood estimates (and covariance matrix), and summarise the transformed
+#' estimates.  See \code{\link{pmatrix.msm}}.
+#' 
+#' All objects used in the original call to \code{\link{msm}} which produced
+#' \code{x}, such as the \code{qmatrix}, should be in the working environment,
+#' or else \code{boot.msm} will produce an \dQuote{object not found} error.
+#' This enables \code{boot.msm} to refit the original model to the replicate
+#' datasets.  However there is currently a limitation.  In the original call to
+#' \code{msm}, the \code{"formula"} argument should be specified directly, as,
+#' for example,
+#' 
+#' \code{msm(state ~ time, data = ...)}
+#' 
+#' and not, for example,
+#' 
+#' \code{form = data$state ~ data$time}
+#' 
+#' \code{msm(formula=form, data = ...)}
+#' 
+#' otherwise \code{boot.msm} will be unable to draw the replicate datasets.
+#' 
+#' \code{boot.msm} will also fail with an incomprehensible error if the
+#' original call to msm used a used-defined object whose name is the same as a
+#' built-in R object, or an object in any other loaded package.  For example,
+#' if you have called a Q matrix \code{q}, when \code{q()} is the built-in
+#' function for quitting R.
+#' 
+#' If \code{stat} is \code{NULL}, then \code{B} different \code{msm} model
+#' objects will be stored in memory. This is unadvisable, as \code{msm} objects
+#' tend to be large, since they contain the original data used for the
+#' \code{msm} fit, so this will be wasteful of memory.
+#' 
+#' To specify more than one statistic, write a function consisting of a list of
+#' different function calls, for example,
+#' 
+#' \code{stat = function(x) list (pmatrix.msm(x, t=1), pmatrix.msm(x, t=2))}
+#' 
+#' @param x A fitted msm model, as output by \code{\link{msm}}.
+#' @param stat A function to call on each refitted msm model. By default this
+#' is \code{\link{pmatrix.msm}}, returning the transition probability matrix in
+#' one time unit. If \code{NULL} then no function is computed.
+#' @param B Number of bootstrap resamples.
+#' @param file Name of a file in which to save partial results after each
+#' replicate. This is saved using \code{\link{save}} and can be restored using
+#' \code{\link{load}}, producing an object called \code{boot.list} containing
+#' the partial results.  Not supported when using parallel processing.
+#' @param cores Number of processor cores to use for parallel processing.
+#' Requires the \pkg{doParallel} package to be installed.  If not specified,
+#' parallel processing is not used. If \code{cores} is set to the string
+#' \code{"default"}, the default methods of \code{\link[parallel]{makeCluster}}
+#' (on Windows) or \code{\link[doParallel]{registerDoParallel}} (on Unix-like)
+#' are used.
+#' @param remove.errors If \code{TRUE} then bootstrap refits which resulted in an
+#' error are removed from the returned list, and a message is returned which states the
+#' proportion of failed fits and the first error message.  If \code{FALSE}, then 
+#' the error message for failed refits is placed in the
+#' corresponding component of the returned list. 
+#' @return A list with \code{B} components, containing the result of calling
+#' function \code{stat} on each of the refitted models.  If \code{stat} is
+#' \code{NULL}, then each component just contains the refitted model.  If one
+#' of the \code{B} model fits was unsuccessful and resulted in an error, then
+#' the corresponding list component will contain the error message.
+#' @author C.H.Jackson <chris.jackson@@mrc-bsu.cam.ac.uk>
+#' @seealso \code{\link{qmatrix.msm}}, \code{\link{qratio.msm}},
+#' \code{\link{sojourn.msm}}, \code{\link{ematrix.msm}},
+#' \code{\link{pmatrix.msm}}, \code{\link{pmatrix.piecewise.msm}},
+#' \code{\link{totlos.msm}}, \code{\link{prevalence.msm}}.
+#' @references Efron, B. and Tibshirani, R.J. (1993) \emph{An Introduction to
+#' the Bootstrap}, Chapman and Hall.
+#' @keywords models
+#' @examples
+#' 
+#' \dontrun{
+#'   ## Psoriatic arthritis example
+#'   data(psor)
+#'   psor.q <- rbind(c(0,0.1,0,0),c(0,0,0.1,0),c(0,0,0,0.1),c(0,0,0,0))
+#'   psor.msm <- msm(state ~ months, subject=ptnum, data=psor, qmatrix =
+#'     psor.q, covariates = ~ollwsdrt+hieffusn,
+#'     constraint = list(hieffusn=c(1,1,1),ollwsdrt=c(1,1,2)),
+#'     control = list(REPORT=1,trace=2), method="BFGS")
+#'   ## Bootstrap the baseline transition intensity matrix.  This will take a long time.
+#'   q.list <- boot.msm(psor.msm, function(x)x$Qmatrices$baseline)
+#'   ## Manipulate the resulting list of matrices to calculate bootstrap standard errors.
+#'   apply(array(unlist(q.list), dim=c(4,4,5)), c(1,2), sd)
+#'   ## Similarly calculate a bootstrap 95% confidence interval
+#'   apply(array(unlist(q.list), dim=c(4,4,5)), c(1,2),
+#'         function(x)quantile(x, c(0.025, 0.975)))
+#'   ## Bootstrap standard errors are larger than the asymptotic standard
+#'   ## errors calculated from the Hessian
+#'   psor.msm$QmatricesSE$baseline
+#' }
+#' 
+#' @export boot.msm
+boot.msm <- function(x, stat=pmatrix.msm, B=1000, file=NULL, cores=NULL, remove.errors=TRUE){
     boot.fn <- function(dummy){
         boot.data <- if (x$hmodel$hidden || x$cmodel$ncens) bootdata.subject.msm(x) else bootdata.trans.msm(x)
         x$call$data <- substitute(boot.data)
@@ -124,9 +251,20 @@ boot.msm <- function(x, stat=pmatrix.msm, B=1000, file=NULL, cores=NULL){
             if (!is.null(file)) save(boot.list, file=file)
         }
     }
+    if (remove.errors) boot.list <- handle_refit_errors(boot.list)
     boot.list
 }
 
+handle_refit_errors <- function(blist){
+  errors <- vapply(blist, function(x)inherits(x, "try-error"), TRUE)
+  nerrors <- sum(errors)
+  if (nerrors > 0) {
+    message(sprintf("%s/%s bootstrap refits ended in an error", nerrors, length(blist)))
+    message(sprintf("First error: %s", blist[[min(which(errors))]]))
+  }
+  blist[!errors]
+}
+
 ### Utilities for calculating bootstrap CIs for particular statistics
 
 qmatrix.ci.msm <- function(x, covariates="mean", sojourn=FALSE, cl=0.95, B=1000, cores=NULL) {
@@ -222,15 +360,46 @@ expected.ci.msm <- function(x,
     e.list <- boot.msm(x, function(x){
         expected.msm(x, times, timezero, initstates, covariates, misccovariates, piecewise.times, piecewise.covariates, risk)
     }, B=B, cores=cores)
-    e.tab.array <- array(unlist(lapply(e.list, function(x)x[[1]])), dim=c(dim(e.list[[1]][[1]]), length(e.list)))
-    e.perc.array <- array(unlist(lapply(e.list, function(x)x[[2]])), dim=c(dim(e.list[[1]][[2]]), length(e.list)))
-    e.tab.ci <- apply(e.tab.array, c(1,2), function(x)(quantile(x, c(0.5 - cl/2, 0.5 + cl/2))))
-    e.perc.ci <- apply(e.perc.array, c(1,2), function(x)(quantile(x, c(0.5 - cl/2, 0.5 + cl/2))))
+    e.tab.array <- array(unlist(lapply(e.list, function(x)x[[1]])), 
+                         dim=c(length(times), x$qmodel$nstates+1, length(e.list)))
+    e.perc.array <- array(unlist(lapply(e.list, function(x)x[[2]])), 
+                          dim=c(length(times), x$qmodel$nstates, length(e.list)))
+    e.tab.ci <- apply(e.tab.array, c(1,2), 
+                      function(x)(quantile(x, c(0.5 - cl/2, 0.5 + cl/2))))
+    e.perc.ci <- apply(e.perc.array, c(1,2), 
+                       function(x)(quantile(x, c(0.5 - cl/2, 0.5 + cl/2))))
     res <- list(aperm(e.tab.ci, c(2,3,1)),  aperm(e.perc.ci, c(2,3,1)))
     names(res) <- c("Expected", "Expected percentages")
     res
 }
 
+
+
+#' Update the maximum likelihood estimates in a fitted model object.
+#' 
+#' Update the maximum likelihood estimates in a fitted model object.  Intended for
+#' developer use only.
+#' 
+#' @param x A fitted multi-state model object, as returned by
+#' \code{\link{msm}}.
+#' @param pars Vector of new parameters, in their untransformed real-line
+#' parameterisations, to substitute for the maximum likelihood estimates
+#' corresponding to those in the \code{estimates} component of the fitted model
+#' object (\code{\link{msm.object}}).  The order of the parameters is
+#' documented in \code{\link{msm}}, argument \code{fixedpars}.
+#' @return An updated \code{\link{msm}} model object with the updated maximum
+#' likelihood estimates, but with the covariances / standard errors unchanged.
+#' 
+#' Point estimates from output functions such as \code{\link{qmatrix.msm}},
+#' \code{\link{pmatrix.msm}}, or any related function, can then be evaluated
+#' with the new parameters, and at arbitrary covariate values.
+#' 
+#' This function is used, for example, when computing confidence intervals from
+#' \code{\link{pmatrix.msm}}, and related functions, using the
+#' \code{ci="normal"} method.
+#' @author C. H. Jackson \email{chris.jackson@@mrc-bsu.cam.ac.uk}
+#' @keywords models
+#' @export updatepars.msm
 updatepars.msm <- function(x, pars){
     x.rep <- x
     x.rep$paramdata$params <- pars
@@ -355,8 +524,12 @@ expected.normci.msm <- function(x,
     e.list <- normboot.msm(x, function(x){
         expected.msm(x, times, timezero, initstates, covariates, misccovariates, piecewise.times, piecewise.covariates, risk)
     }, B)
-    e.tab.array <- array(unlist(lapply(e.list, function(x)x[[1]])), dim=c(dim(e.list[[1]][[1]]), length(e.list)))
-    e.perc.array <- array(unlist(lapply(e.list, function(x)x[[2]])), dim=c(dim(e.list[[1]][[2]]), length(e.list)))
+    e_tab_vec <- unlist(lapply(e.list, function(x)x$"Expected"))
+    e.tab.array <- array(e_tab_vec, 
+                         dim=c(length(times), x$qmodel$nstates+1, B))
+    e_perc_vec <- unlist(lapply(e.list, function(x)x$"Expected percentages"))
+    e.perc.array <- array(e_perc_vec, 
+                          dim=c(length(times), x$qmodel$nstates, B))
     e.tab.ci <- apply(e.tab.array, c(1,2), function(x)(quantile(x, c(0.5 - cl/2, 0.5 + cl/2))))
     e.perc.ci <- apply(e.perc.array, c(1,2), function(x)(quantile(x, c(0.5 - cl/2, 0.5 + cl/2))))
     res <- list(aperm(e.tab.ci, c(2,3,1)),  aperm(e.perc.ci, c(2,3,1)))
