@@ -58,6 +58,18 @@ test_that("HMM normal likelihoods: FEV data: covariate on outcome",{
                      hconstraint = list(acute = c(1,1,1,1)),
                      fixedpars=TRUE, center=FALSE))
     expect_equal(49839.1627881087, fev5.hid$minus2loglik, tol=1e-06)
+    
+    ## Viterbi
+    vit <- viterbi.msm(fev3.hid)
+    expect_equal(vit$fitted[1:10], rep(1,10))
+    
+    if (0){ # substitute() as used in viterbi.msm doesn't work within testthat, 
+            # so run this test by hand
+        datsub <- fev[fev[,"ptnum"]==1,,drop=FALSE]
+        vit2 <- viterbi.msm(fev3.hid, newdata=datsub)
+        expect_equal(vit$fitted[1:10], vit2$fitted[1:10])
+        expect_equal(vit$pstate.1[1:10], vit2$pstate.1[1:10])
+    }
 })
 
 context("Hidden Markov model error handling")
@@ -151,3 +163,84 @@ test_that("error handling in HMM fits",{
     expect_error(fev3.hid <- msm(fev ~ days, subject=ptnum, data=fev, qmatrix=three.q, deathexact=3, hmodel=hmodel3, hcovariates=list(~acute, ~acute, NULL), hcovinits = list(-8, -8, NULL), hconstraint = list(sderr=c("wrong length"), acute = c(1,1))), "constraint for \"sderr\" of length 1, should be 2")
 
 })
+
+test_that("HMM normal model fit",{
+  three.q <- rbind(c(0, exp(-6), exp(-9)), c(0, 0, exp(-6)), c(0, 0, 0))
+  hmodel1 <- list(hmmNorm(mean=100, sd=16), hmmNorm(mean=54, sd=18), hmmIdent(999))
+  fev1.msm <- msm(fev ~ days, subject=ptnum, data=fev[1:500,], qmatrix=three.q, death=3, hmodel=hmodel1,
+                  hcovariates=list(~acute, ~acute, NULL), hcovinits = list(-8, -8, NULL),
+                  hconstraint = list(acute = c(1,1)), center=FALSE)
+  print(fev1.msm)
+  expect_equal(4269.77165605886, fev1.msm$minus2loglik, tol=1e-06)
+  
+  fev1.msm <- msm(fev ~ days, subject=ptnum, data=fev[1:1000,], qmatrix=three.q, death=3, hmodel=hmodel1,
+                  hcovariates=list(~acute, ~acute, NULL), hcovinits = list(-8, -8, NULL),
+                  hconstraint = list(acute = c(1,1)), center=FALSE,
+                  hranges = list(mean=list(lower=c(60,50),upper=c(110,80)),
+                                 sd=list(lower=c(11,13),upper=c(20,20))))
+  expect_gt(fev1.msm$hmodel$pars[1], 60)
+  expect_lt(fev1.msm$hmodel$pars[1], 110)
+})
+
+test_that("HMM categorical model fit",{
+  skip_on_cran()
+  misccov.msm <- msm(state ~ years, subject = PTNUM, data = cav[1:1000,],  
+                     qmatrix = oneway4.q, ematrix=ematrix, death = 4, 
+                     misccovariates = ~dage + sex, fixedpars=c(11, 17))
+  misccovnew.msm <- msm(state ~ years, subject = PTNUM, data = cav[1:1000,],  
+                        qmatrix = oneway4.q, death = 4,
+                        fixedpars=c(11,17), # sex on state 2|1, 2|3
+                        hmodel=list(
+                          hmmCat(prob=c(0.9, 0.1, 0, 0)),
+                          hmmCat(prob=c(0.1, 0.8, 0.1, 0)),
+                          hmmCat(prob=c(0, 0.1, 0.9, 0)), hmmIdent()),
+                        hcovariates=list(~dage + sex, ~dage + sex, ~dage + sex, ~1)
+  )
+  print(misccovnew.msm)
+  expect_equal(misccov.msm$minus2loglik, misccovnew.msm$minus2loglik)
+})
+
+
+test_that("initcovariates",{
+  expect_error({
+    (fev3.hid <- msm(fev ~ days, subject=ptnum, data=fev,
+                     qmatrix=three.q, deathexact=3, hmodel=hmodel3, fixedpars=TRUE,
+                     initcovariates = ~acute))
+    (fev3.hid <- msm(fev ~ days, subject=ptnum, data=fev,
+                     qmatrix=three.q, deathexact=3, hmodel=hmodel3, fixedpars=TRUE,
+                     initprobs = c(0.9, 0.1, 0.1), est.initprobs = TRUE,
+                     initcovariates = ~acute, initcovinits = list(acute=c(0.1,0.1))))
+  }, NA)
+})
+
+
+test_that("HMMs with one observation for a subject", {
+  hmodel1 <- list(hmmNorm(mean=100, sd=16), hmmNorm(mean=54, sd=18), hmmIdent(999))
+  fevno1 <- fev
+  fevno1 <- fevno1[fevno1$ptnum != 1,]
+  fev1 <- fev
+  fev1 <- fev1[!(fev1$ptnum==1 & fev1$days>191), ]
+  head(fev1)
+  head(fevno1)
+  fev1.msm <- msm(fev ~ days, subject=ptnum, data=fev1, qmatrix=three.q, 
+                  death=3, hmodel=hmodel1, fixedpars=TRUE)
+  fev1.msm
+  
+  fevno1.msm <- msm(fev ~ days, subject=ptnum, data=fevno1, qmatrix=three.q, 
+                    death=3, hmodel=hmodel1, fixedpars=TRUE)
+  
+  ## Check gives same result as inserting a uninformative censored state 
+  ## at the second obs 
+  censrow <- data.frame(ptnum=1, days=200, fev=-99, acute=0)
+  fevcens <- rbind(fev1[1,], censrow, fev1[-1,])
+  fevcens$obstrue <- NA
+  fevcens$obstrue[2] <- 1 # watch this syntax for censor+hmm! See help(msm)
+  fevcens.msm <- msm(fev ~ days, subject=ptnum, data=fevcens, qmatrix=three.q, 
+                     death=3, hmodel=hmodel1, censor=-99, censor.states = 1:3,
+                     obstrue = obstrue, fixedpars=TRUE)
+  fevcens.msm
+
+  expect_equal(logLik.msm(fev1.msm), logLik.msm(fevcens.msm))
+  
+  expect_true(logLik.msm(fevno1.msm) != logLik.msm(fevcens.msm))
+})
